==> sharyn-4.30.0.tgz: package/webpack-config/index.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _stringify = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/json/stringify"));

var _webpack = _interopRequireDefault(require("webpack"));

var _path = _interopRequireDefault(require("path"));

var _checkSetup = require("@sharyn/check-setup");

var _appRootPath = require("app-root-path");

var _wdsUtil = require("./wds-util");

/* eslint-disable import/no-extraneous-dependencies, global-require, import/no-dynamic-require, no-empty */
// flow-disable-next-line
var config = {
  entry: './src/_client/client.js',
  output: {
    filename: "js/bundle.js",
    chunkFilename: '[name].[chunkhash].js',
    path: _path.default.resolve('dist'),
    publicPath: '/static/'
  },
  module: {
    rules: [{
      test: /\.js$/,
      exclude: /node_modules/,
      use: {
        loader: 'babel-loader'
      }
    }]
  },
  plugins: [],
  resolve: {
    alias: {
      joi: 'joi-browser'
    }
  },
  performance: {
    hints: false
  }
};
var packageJson;

try {
  // flow-disable-next-line
  packageJson = require("".concat(_appRootPath.path, "/package.json"));
} catch (err) {}

if (packageJson && packageJson.version) {
  config.plugins.push(new _webpack.default.DefinePlugin({
    CLIENT_VERSION: (0, _stringify.default)(packageJson.version)
  }));
}

if ((0, _checkSetup.hasPackage)('compression-webpack-plugin')) {
  // flow-disable-next-line
  var CompressionPlugin = require('compression-webpack-plugin');

  config.plugins.push(new CompressionPlugin());
}

if (_wdsUtil.WDS_PORT) {
  config.output.publicPath = "http://localhost:".concat(_wdsUtil.WDS_PORT, "/static/");
  config.devServer = {
    port: _wdsUtil.WDS_PORT,
    headers: {
      'Access-Control-Allow-Origin': '*'
    }
  };
}

module.exports = config;

==> sharyn-4.32.2.tgz: package/webpack-config/index.js <==
"use strict";

var _interopRequireDefault = require("@babel/runtime-corejs2/helpers/interopRequireDefault");

var _stringify = _interopRequireDefault(require("@babel/runtime-corejs2/core-js/json/stringify"));

var _webpack = _interopRequireDefault(require("webpack"));

var _path = _interopRequireDefault(require("path"));

var _checkSetup = require("@sharyn/check-setup");

var _wdsUtil = require("./wds-util");

/* eslint-disable import/no-extraneous-dependencies, global-require */
// flow-disable-next-line
var config = {
  entry: './src/_client/client.js',
  output: {
    filename: "js/bundle.js",
    chunkFilename: '[name].[chunkhash].js',
    path: _path.default.resolve('dist'),
    publicPath: '/static/'
  },
  module: {
    rules: [{
      test: /\.js$/,
      exclude: /node_modules/,
      use: {
        loader: 'babel-loader'
      }
    }]
  },
  plugins: [new _webpack.default.DefinePlugin({
    CLIENT_VERSION: (0, _stringify.default)((0, _checkSetup.dirChecksum)('.'))
  })],
  resolve: {
    alias: {
      joi: 'joi-browser'
    }
  },
  performance: {
    hints: false
  }
};

if ((0, _checkSetup.hasPackage)('compression-webpack-plugin')) {
  // flow-disable-next-line
  var CompressionPlugin = require('compression-webpack-plugin');

  config.plugins.push(new CompressionPlugin());
}

if (_wdsUtil.WDS_PORT) {
  config.output.publicPath = "http://localhost:".concat(_wdsUtil.WDS_PORT, "/static/");
  config.devServer = {
    port: _wdsUtil.WDS_PORT,
    headers: {
      'Access-Control-Allow-Origin': '*'
    }
  };
}

module.exports = config;
